@@ -1,32 +1,28 @@
 package Data::Serializer::XML::Simple;
 BEGIN { @Data::Serializer::XML::Simple::ISA = qw(Data::Serializer) }
 
-
+use warnings;
 use strict;
 use XML::Simple qw(); 
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA);
 
-require Exporter;
-require AutoLoader;
-
-@ISA = qw(Exporter AutoLoader);
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-@EXPORT = qw(
-	
-);
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 
+sub serialize {
+    my $self = (shift);
+    my $xml = XML::Simple->new(keyattr => [ 'name']);
+    return $xml->XMLout( (shift) );
+}
 
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
+sub deserialize {
+    my $xml = XML::Simple->new(keyattr => [ 'name']);
+    return $xml->XMLin($_[1]);
+}
 
 1;
 __END__
-# Below is the stub of documentation for your module. You better edit it!
+# 
 
 =head1 NAME
 
@@ -43,6 +39,15 @@ Module is used internally to Data::Serializer
 The only option currently supported is B<dtd>.  This just calls the dtd method of XML::Simple
 prior to serializing the data.   See XML::Simple(3) for details.
 
+
+=over 4
+
+=item B<serialize> - Wrapper to normalize serializer method name
+
+=item B<deserialize> - Wrapper to normalize deserializer method name
+
+=back
+
 =head1 AUTHOR
  
 Neil Neely <neil@neely.cx>
@@ -59,14 +64,4 @@ perl(1), Data::Serializer(3), XML::Simple(3).
 
 =cut
 
-sub serialize {
-    my $self = (shift);
-    my $xml = XML::Simple->new(keyattr => [ 'name']);
-    return $xml->XMLout( (shift) );
-}
-
-sub deserialize {
-    my $xml = XML::Simple->new(keyattr => [ 'name']);
-    return $xml->XMLin($_[1]);
-}
 
